@@ -1,6 +1,6 @@
-linux-6.6.117-sparky-lts66 for Debian
+linux-6.6.119-sparky-lts66 for Debian
 ------------------------------------
 
 <Possible notes regarding this package - if none, delete this file.>
 
- -- pavroo <pavroo@onet.eu>  Mon, 24 Nov 2025 17:19:48 +0100
+ -- pavroo <pavroo@onet.eu>  Sun, 07 Dec 2025 11:40:53 +0100
