@@ -1,4 +1,4 @@
-linux-6.6.117-sparky-lts66 for Debian
+linux-6.6.119-sparky-lts66 for Debian
 ------------------------------------
 
 <This file describes information about the source package, see Debian policy
@@ -6,4 +6,4 @@ manual section 4.14. You WILL either need to modify or delete this file.>
 
 
 
- -- pavroo <pavroo@onet.eu>  Mon, 24 Nov 2025 17:19:48 +0100
+ -- pavroo <pavroo@onet.eu>  Sun, 07 Dec 2025 11:40:53 +0100
