@@ -20,14 +20,14 @@ manpage.1: manpage.sgml
   <!ENTITY dhfirstname "<firstname>FIRSTNAME</firstname>">
   <!ENTITY dhsurname   "<surname>SURNAME</surname>">
   <!-- Please adjust the date whenever revising the manpage. -->
-  <!ENTITY dhdate      "<date>November 24 2025</date>">
+  <!ENTITY dhdate      "<date>December  7 2025</date>">
   <!-- SECTION should be 1-8, maybe w/ subsection other parameters are
        allowed: see man(7), man(1). -->
   <!ENTITY dhsection   "<manvolnum>SECTION</manvolnum>">
   <!ENTITY dhemail     "<email>pavroo@onet.eu</email>">
   <!ENTITY dhusername  "pavroo">
-  <!ENTITY dhucpackage "<refentrytitle>Linux-6.6.117-sparky-lts66</refentrytitle>">
-  <!ENTITY dhpackage   "linux-6.6.117-sparky-lts66">
+  <!ENTITY dhucpackage "<refentrytitle>Linux-6.6.119-sparky-lts66</refentrytitle>">
+  <!ENTITY dhpackage   "linux-6.6.119-sparky-lts66">
 
   <!ENTITY debian      "<productname>Debian</productname>">
   <!ENTITY gnu         "<acronym>GNU</acronym>">
